<?php

/*
	phpblock_GalleryBlock()

	by Andy Maloney [asmaloney@users.sf.net]

	Inspired by the 'Gallery Last Updated' and 'Gallery Top 10' blocks at
	www.squatty.com by Danny Ledger and others.
*/
function GalleryBlock()
{
	global $GALLERY_BASEDIR;
	global $GB_CONF;
	global $gallery;  
	global $galleryCache;  

	require_once( "config.php" );
	require_once( $GALLERY_BASEDIR . "init.php" );
	require_once( $_CONF['path_html'] . "galleryblock/galleryblock.php" );


	$galleryCache = new GalleryBlockCache();

	$numAlbums = $galleryCache->albumDB->numAlbums( $gallery->user );

	if ( $numAlbums == 0 )
	{
		if ( $GB_CONF['no_albums_show'] == 1 )
		{
			return $GB_CONF['no_albums_text'];
		}
		
		return;	// do not show the block
	}

	$retval = "";

	if ( $GB_CONF['ht_show'] == 1 )
	{
		$numPhotos = $galleryCache->albumDB->numPhotos( $gallery->user );

		$header = str_replace( "%numphotos", $numPhotos, $GB_CONF['ht_text'] );
		$header = str_replace( "%numalbums", $numAlbums, $header );

		$retval .= $header;
		$retval .= "<br><br>";
	}

	define( GB_NUM_ALBUMS, count( $galleryCache->albumData ) );

	if ( $GB_CONF['lu_show'] == 1 )
	{
		$retval .= ShowLatestUpdates( $GB_CONF['lu_num_albums'], GB_NUM_ALBUMS );
	}

	if ( ($GB_CONF['lu_show'] == 1) && ($GB_CONF['mv_show'] == 1) )
	{
		$retval .= "<br><br>";
	}

	if ( $GB_CONF['mv_show'] == 1 )
	{
		$retval .= ShowMostViewed( $GB_CONF['mv_num_albums'], GB_NUM_ALBUMS );
	}

	return $retval;
}

// ShowLatestUpdates
function ShowLatestUpdates( $howMany, $numAlbums ) 
{
	global $GB_CONF;  
	global $galleryCache;  

	
	$galleryCache->NumericDescendingSort( "last_mod_time" );

	$retval = "";
	$retval .= "<b>" . $GB_CONF['lu_title'] . "</b>";
	$retval .= "<hr>";

	$counter = 0;

	foreach ( $galleryCache->albumData as $key => $entry )
	{
		$albumURL = makeGalleryUrl( $entry['name'] );

		if ( $entry['new_update'] && ($GB_CONF['lu_image_path'] != "") )
		{
			$title = "title='" . $entry['title'] . " - " . $entry['num_photos'] . " photos'";
			$width = "width=" . $GB_CONF['lu_image_width'];
			$height = "height=" . $GB_CONF['lu_image_height'];
			$retval .= "<img src='" . $GB_CONF['lu_image_path'] . "' align=right $width $height $title>";
		}

		$retval .= "&nbsp;<a href=" . $albumURL . ">" . $entry['title'] . "</a>";

		if ( $GB_CONF['lu_date_format'] != "" )
		{
			$retval .= "<br>";
			$retval .= "&nbsp;&nbsp; " . $entry['last_mod_str'];
		}

		$counter++;
		if ( $counter == $howMany || $counter == $numAlbums )
		{
			break;
		}

		$retval .= "<br>";
	}

	return $retval;
}

// ShowMostViewed
function ShowMostViewed( $howMany, $numAlbums )
{
	global $GB_CONF;  
	global $galleryCache;  


	$galleryCache->NumericDescendingSort( "clicks" );

	$retval = "";
	$retval .= "<b>" . $GB_CONF['mv_title'] . "</b>";
	$retval .= "<hr>";

	$counter = 0;

	foreach ( $galleryCache->albumData as $key => $entry )
	{
		$albumURL = makeGalleryUrl( $entry['name'] );
		$retval .= "&nbsp;<a href=" . $albumURL . "><span>" . $entry['title'] . "</span></a>";

		$retval .= str_replace( "%hits", $entry['clicks'], $GB_CONF['mv_text'] );

		$counter++;
		if ( $counter == $howMany || $counter == $numAlbums )
		{
			break;
		}

		$retval .= "<br>";
	}

	return $retval;
}

?>
