<?php
/*
	galleryblock.php

	by Andy Maloney [asmaloney@users.sf.net]

	Inspired by the 'Gallery Last Updated' and 'Gallery Top 10' blocks at
	www.squatty.com by Danny Ledger and others.
*/

class GalleryBlockCache
{
	var	$cacheFileName;
	var	$cacheDelimiter;
	var	$cacheExpireTime;
	var	$albumData;
	var	$albumDB;
	var	$dateTimeFormat;
	var	$newUpdateInterval;


	// constructor
	function GalleryBlockCache()
	{
		global $GB_CONF;


		$this->cacheFileName = $GB_CONF['cache_file'];
		$this->cacheDelimiter = $GB_CONF['cache_delimiter'];
		$this->cacheExpireTime = $GB_CONF['cache_expiry'];
		$this->albumDB = new AlbumDB();
		$this->dateTimeFormat = $GB_CONF['lu_date_format'];
		$this->newUpdateInterval = $GB_CONF['lu_new_update_interval'];

		$this->UpdateCache();
		$this->ReadCache();
	}

	// NumericDescendingSort 
	function NumericDescendingSort( $field )
	{
		if ( !array_key_exists( $field, $this->albumData[0] ) )
		{
			// error
			return FALSE;
		}
		
		foreach ( $this->albumData as $key => $entry )
		{
			$index_array[$key] = $entry[$field];
		}
		array_multisort( $index_array, SORT_DESC, SORT_NUMERIC, $this->albumData );

		return TRUE;
	}

	// UpdateCache
	function UpdateCache()
	{
		// check our cache time
		$mtime = filemtime( $this->cacheFileName );

		if ( $mtime != FALSE )
		{
			if ( (time() - $mtime) < $this->cacheExpireTime )
			{
				return;
			}
		}

		unset( $this->albumData );

		foreach ( $this->albumDB->albumList as $album )
		{
			// only interested in root albums
			if ( !$album->isRoot() )
			{
				continue;
			}

			$last_mod_time = $album->fields["last_mod_time"];

			if ( (time() - $last_mod_time) < $this->newUpdateInterval )
			{
				$newUpdate = 1;
			}
			else
			{
				$newUpdate = 0;
			}

			$this->albumData[] = array(
				"name" => $album->fields["name"],
				"title" => $album->fields["title"],
				"last_mod_time" => $last_mod_time,
				"last_mod_str" =>  strftime( $this->dateTimeFormat, $album->fields["last_mod_time"] ),
				"new_update" => $newUpdate,
				"num_photos" => $album->numPhotos(),
				"clicks" => $album->getClicks()
			);
		}

		if ( $fd = fs_fopen( $this->cacheFileName, "w" ) )
		{
			foreach ( $this->albumData as $entry )
			{
				$imp = implode( $this->cacheDelimiter, $entry );
				fwrite( $fd, "$imp\n" );
			}

			fclose( $fd );

			chmod( $this->cacheFileName, 0600 );
		}
	}

	// ReadCache
	function ReadCache()
	{
		global $gallery;

		if ( !file_exists( $this->cacheFileName ) )
		{
			return FALSE;	
		}

		$contents = file( $this->cacheFileName );
		
		unset( $this->albumData );

		// stuff data into array
		foreach ( $contents as $entry )
		{
			$entry = rtrim( $entry );
			list( $name, $title, $last_mod_time, $last_mod_str, $newUpdate, $num_photos, $clicks ) = explode( $this->cacheDelimiter, $entry );

			$album = $this->albumDB->getAlbumbyName( $name, FALSE );

			if ( $gallery->user->canReadAlbum($album) )
			{
				$this->albumData[] = array(
					"name" => $name,
					"title" => $title,
					"last_mod_time" => $last_mod_time,
					"last_mod_str" => $last_mod_str,
					"new_update" => $newUpdate,
					"num_photos" => $num_photos,
					"clicks" => $clicks
				);
			}
		}

		return TRUE;
	}
}

?>
